<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" label-width="68px">
      <el-form-item label="体检号" prop="tjNumber">
        <el-input v-model="queryParams.tjNumber" placeholder="请输入体检号" clearable @keyup.enter.native="handleQuery"
          style="width: 170px" />
      </el-form-item>
      <el-form-item label="姓名" prop="name">
        <el-input v-model="queryParams.name" placeholder="请输入姓名" clearable @keyup.enter.native="handleQuery"
          style="width: 110px" />
      </el-form-item>
      <el-form-item label="登记时间" prop="createTimeList">
        <el-date-picker v-model="createTimeList" type="datetimerange" align="right" :picker-options="pickerOptions"
          style="width: 310px" start-placeholder="开始日期" end-placeholder="结束日期" :default-time="['00:00:00', '23:00:00']"
          format="yyyy-MM-dd HH:mm" value-format="yyyy-MM-dd HH:mm" @change="dateChangebirthday1">
        </el-date-picker>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">查询</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>
    <el-radio-group v-model="checkStatus" @input="radioChange" style="margin: 10px 15px">
      <el-radio-button label="0">未审核</el-radio-button>
      <el-radio-button label="1">已审核</el-radio-button>
    </el-radio-group>

    <div style="width: 100%; margin-left: 10px; display: flex">
      <div style="width: 40%; margin-right: 20px">
        <el-table id="ta" v-loading="loading" ref="tb" :data="exaList" border height="520px"
          @selection-change="handleSelectionChange" :row-class-name="tableRowClassName">
          <el-table-column type="selection" width="40" align="center" />
          <el-table-column label="体检号" align="center" prop="tjNumber" width="160px" />
          <el-table-column label="姓名" align="center" prop="cusName" width="80px" />
          <el-table-column label="性别" align="center" prop="cusSex" width="60px">
            <template slot-scope="scope">
              <!-- {{scope.row.customer.cusSex}} -->
              {{ scope.row.cusSex === 0 ? "男" : "女" }}
              <!-- <dict-tag :options="dict.type.sys_user_sex" :value="scope.row.cusSex " /> -->
            </template>
          </el-table-column>
          <el-table-column label="手机号" align="center" prop="cusPhone" width="120px" />
          <el-table-column label="登记时间" align="center" prop="tjTime" width="120px" />
          <el-table-column v-if="checkStatus == '1'" label="审核状态" align="center" prop="confirmStatus" width="110px">
            <template slot-scope="scope">
              <span :style="{ color: scope.row.confirmStatus == '301' ? '#0CB618' : '#EA1B29', }"
                v-if="scope.row.confirmStatus == '301'">已通过</span>
              <span :style="{ color: scope.row.confirmStatus == '301' ? '#0CB618' : '#EA1B29', }"
                v-if="scope.row.confirmStatus == '299'">已驳回</span>
            </template>
          </el-table-column>
          <el-table-column label="操作" align="center">
            <template slot-scope="scope">
              <el-button size="mini" type="text" v-hasPermi="['reservation:reservation:edit']"
                v-show="scope.row.confirmStatus == '299' || scope.row.confirmStatus == 288"
                @click="tongguo(scope.row)">通过</el-button>
              <el-button size="mini" type="text" v-hasPermi="['reservation:reservation:edit']"
                v-show="scope.row.confirmStatus == '301' || scope.row.confirmStatus == 288"
                @click="bohui(scope.row)">撤销</el-button>
            </template>
          </el-table-column>
        </el-table>
      </div>
      <div style="width: 50%">
        <el-table v-loading="loading" border height="520px" ref="tab1" :data="xiangmuList">
          <!-- <el-table-column type="selection" width="40" align="center" /> -->
          <el-table-column label="部门" align="center" prop="deptName" :show-overflow-tooltip="true" />
          <el-table-column label="项目" align="center" prop="proName" width="140" />
          <el-table-column label="状态" align="center" prop="type" :show-overflow-tooltip="true" width="60">
            <template slot-scope="scope">
              <span v-if="scope.row.type == '0'">未检</span>
              <span v-if="scope.row.type == '1'">已检</span>
              <span v-if="scope.row.type == '2'">弃检</span>
              <span v-if="scope.row.type == '3'">延期</span>
            </template>
          </el-table-column>

          <el-table-column label="收费方式" align="center" prop="sffs" :show-overflow-tooltip="true" width="80" />
          <el-table-column label="是否收费" align="center" prop="isPay" :show-overflow-tooltip="true" />
          <!-- <el-table-column
            label="签到时间"
            align="center"
            prop="qdcreateTime"
            width="160"
          /> -->
          <el-table-column label="检查医生" align="center" prop="doctorName" width="100" />
          <el-table-column label="检查时间" align="center" prop="bcupdateTime" width="160" />
          <!-- <el-table-column
            label="保存医生"
            align="center"
            prop="bcdoctorName"
            width="120"
          /> -->
          <el-table-column label="最后修改时间" align="center" prop="zhupdateTime" width="160" />
        </el-table>
      </div>
    </div>
    <div style="margin-right: 67%">
      <!-- <el-pagination @size-change="handleSizeChange" @current-change="handleCurrentChange" :pager-count="5" :current-page.sync="currentPage1" :current-page="page"
                :page-sizes="pageSize" :page-size="size" layout="total, sizes, prev, pager, next, jumper" :total="total">
            </el-pagination> -->
      <pagination v-show="total > 0" :total="total" :page.sync="queryParams.page" :limit.sync="queryParams.pageSize"
        @pagination="getList" />
    </div>
  </div>
</template>

<script>
import { getCsList, confirmOrder, cSWebGetPro } from "@/api/doctor/examination";
export default {
  dicts: ["dict_tj_status"],
  data() {
    return {
      createTimeList: "",
      total: 0,
      loading: true,
      // 查询参数
      queryParams: {
        page: 1,
        pageSize: 20,
        checkStatus: null,
        tjNumber: null,
        compId: null,
        name: null,
        beginTime: null,
        endTime: null,
      },
      // 绑定单选按钮
      checkStatus: "0",
      exaList: [],
      // 表单参数
      form: {},
      tjNumbers: "",
      multipleSelection: "",
      tjnum: "",
      xiangmuList: [],
      selectList: [],
      tg: true,
      bh: true,
      pickerOptions: {
        shortcuts: [
          {
            text: "最近一周",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "最近一个月",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "最近三个月",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
              picker.$emit("pick", [start, end]);
            },
          },
        ],
      },
    };
  },
  created() {
    this.getList();
    // this.getNowTime();
  },
  methods: {
    // / 处理默认选中当前日期
    getNowTime() {
      var curDate = new Date().getTime();
      var dayNum = 7 * 24 * 3600 * 1000;
      var threeDays = curDate - dayNum;
      var sDay = this.getLocalTime(threeDays);
      var end = this.getLocalTime(curDate);
      this.createTimeList = [sDay, end];
    },
    add0(m) {
      return m < 10 ? "0" + m : m;
    },
    getLocalTime(nS) {
      var time = new Date(nS);
      var y = time.getFullYear();
      var m = time.getMonth() + 1;
      var d = time.getDate();
      var h = time.getHours();
      var mm = time.getMinutes();
      return (
        y +
        "-" +
        this.add0(m) +
        "-" +
        this.add0(d) +
        " " +
        this.add0(h) +
        ":" +
        this.add0(mm)
      );
    },

    dateChangebirthday1(val) {
      this.startTime = val;
    },
    getList() {
      this.loading = true
      this.queryParams.checkStatus = "0";
      this.queryParams.beginTime = this.createTimeList[0];
      this.queryParams.endTime = this.createTimeList[1];
      getCsList(this.queryParams).then((res) => {
        if (res.code == 200) {
          this.loading = false
          if (res.data) {
            this.exaList = res.data.customers;
            this.total = res.data.total;
            if (this.exaList.length != 0) {
              this.$nextTick(() => {
                this.$refs.tb.toggleRowSelection(this.exaList[0], true);
              });
            } else {
              this.$refs.tb.clearSelection();
            }
            this.total = res.data.total;
          } else {
            this.exaList = [];
            this.tableList = [];
          }
        }

      });
    },
    // 单选按钮
    radioChange(value) {
      this.loading = true;
      this.queryParams.checkStatus = value;
      getCsList(this.queryParams).then((response) => {
        if (response.code == 200) {
          this.exaList = response.data.customers;
          if (this.exaList.length != 0) {
            this.$nextTick(() => {
              this.$refs.tb.toggleRowSelection(this.exaList[0], true);
            });
          } else {
            this.$refs.tb.clearSelection();
            this.xiangmuList = [];
          }
          this.total = response.data.total;
          this.loading = false;
        }

      });
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.page = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
      this.loading = true;
    },
    // 单选框选中数据
    handleSelectionChange(selection) {
      this.selectList = selection;
      this.multipleSelection = [];
      if (selection.length > 1) {
        this.$refs.tb.clearSelection();
        this.$refs.tb.toggleRowSelection(selection[selection.length - 1]);
      }
      this.multipleSelection = selection[selection.length - 1]
        ? [selection[selection.length - 1]]
        : [];
      this.multipleSelection.forEach((element) => {
        this.tjnum = element.tjNumber;
        let tjNumber = this.tjnum;
        cSWebGetPro(tjNumber).then((res) => {
          this.xiangmuList = res.data;
        });
      });
    },
    tableRowClassName({ row, rowIndex }) {
      for (let i = 0; i < this.selectList.length; i++) {
        if (row === this.selectList[i]) {
          return "warning-row";
        }
      }
    },
    // 通过按钮
    tongguo(row) {
      this.tjNumbers = row.tjNumber;
      this.$confirm("是否通过", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      }).then(() => {
        let data = {
          tjNumber: this.tjNumbers,
          status: "0",
        };
        confirmOrder(data).then((res) => {
          if (res.code == 200) {
            this.getList();
            this.$modal.msgSuccess("提交成功！");
          }
        });
      });
    },
    // 驳回按钮
    bohui(row) {
      this.tjNumbers = row.tjNumber;
      this.$confirm("是否驳回", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning",
      }).then(() => {
        let data = {
          tjNumber: this.tjNumbers,
          status: "1",
        };
        confirmOrder(data).then((res) => {
          if (res.code == 200) {
            this.getList();
            this.$modal.msgSuccess("提交成功！");
          }
        });
      });
    },
  },
};
</script>

<style lang="scss" scoped>
#ta .el-table__header-wrapper .el-checkbox {
  display: none;
}

.el-table .warning-row {
  background: #e5f3ff !important;
}
</style>